@@ -11,6 +11,8 @@
 ;; xemacs19, emacs20, xemacs20...).  The compiled code is then
 ;; installed in a subdirectory of the respective site-lisp directory.
 ;; We have to add this to the load-path:
-(setq load-path (nconc load-path (list (concat "/usr/share/"
-                                               (symbol-name flavor)
-                                               "/site-lisp/#PACKAGE#"))))
+(setq load-path (cons (concat "/usr/share/"
+                              (symbol-name flavor)
+			      "/site-lisp/#PACKAGE#") load-path))
+
+
